@@ -21,7 +21,6 @@
 
 #include <QList>
 #include <QObject>
-#include <QVector>
 
 namespace StepCore
 {
@@ -32,7 +31,7 @@ namespace StepCore
 class Clipboard : public QObject
 {
 public:
-    Clipboard(QObject* parent = 0);
+    explicit Clipboard(QObject* parent = 0);
     
     void copy(const QList<StepCore::Item*>& items);
     QList<StepCore::Item*> paste(const StepCore::Factory* factory);
