@@ -55,7 +55,7 @@ int main(int argc, char* argv[])
                          i18n(description),
                          KAboutLicense::GPL,
                          i18n("(C) 2007 Vladimir Kuznetsov"),
-                         i18n("http://edu.kde.org/step")
+                         i18n("https://edu.kde.org/step")
     );
 
     aboutData.addAuthor(
@@ -73,8 +73,6 @@ int main(int argc, char* argv[])
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
 
     QCommandLineOption option(QStringList() << QStringLiteral("+[url]") << i18n( "Document to open" ));
     parser.addOption(option);
